.. QHist documentation master file, created by
   sphinx-quickstart on Fri Apr  6 15:18:30 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. mdinclude:: ../../README.md


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
